Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Response ¶
type Response struct {
// Data contains the raw data returned from the server.
// TODO: implement function to pipe this straight to Gemtext parser
Data []byte
// MetaData contains the metadata of the response.
// If StatusCode == 20, it is the MIME type associated with the data
MetaData string
// StatusCode contains the status code returned by the server.
// If this is not 20, Data should be considered to be empty
StatusCode int
}
Response represents a Gemini Response
Click to show internal directories.
Click to hide internal directories.